Struct ballista_cli::helper::CliHelper
source · pub struct CliHelper { /* private fields */ }Trait Implementations
sourceimpl Completer for CliHelper
impl Completer for CliHelper
sourcefn complete(
&self,
line: &str,
pos: usize,
ctx: &Context<'_>
) -> Result<(usize, Vec<Pair, Global>), ReadlineError>
fn complete(
&self,
line: &str,
pos: usize,
ctx: &Context<'_>
) -> Result<(usize, Vec<Pair, Global>), ReadlineError>
Takes the currently edited
line with the cursor position and
returns the start position and the completion candidates for the
partial word to be completed. Read moresourcefn update(&self, line: &mut LineBuffer, start: usize, elected: &str)
fn update(&self, line: &mut LineBuffer, start: usize, elected: &str)
Updates the edited
line with the elected candidate.sourceimpl Highlighter for CliHelper
impl Highlighter for CliHelper
sourcefn highlight<'l>(&self, line: &'l str, pos: usize) -> Cow<'l, str>
fn highlight<'l>(&self, line: &'l str, pos: usize) -> Cow<'l, str>
Takes the currently edited
line with the cursor position and
returns the highlighted version (with ANSI color). Read moresourcefn highlight_prompt<'b, 's, 'p>(
&'s self,
prompt: &'p str,
default: bool
) -> Cow<'b, str>where
's: 'b,
'p: 'b,
fn highlight_prompt<'b, 's, 'p>(
&'s self,
prompt: &'p str,
default: bool
) -> Cow<'b, str>where
's: 'b,
'p: 'b,
Takes the
prompt and
returns the highlighted version (with ANSI color). Read moresourcefn highlight_hint<'h>(&self, hint: &'h str) -> Cow<'h, str>
fn highlight_hint<'h>(&self, hint: &'h str) -> Cow<'h, str>
Takes the
hint and
returns the highlighted version (with ANSI color). Read moresourcefn highlight_candidate<'c>(
&self,
candidate: &'c str,
completion: CompletionType
) -> Cow<'c, str>
fn highlight_candidate<'c>(
&self,
candidate: &'c str,
completion: CompletionType
) -> Cow<'c, str>
Takes the completion
candidate and
returns the highlighted version (with ANSI color). Read moresourceimpl Validator for CliHelper
impl Validator for CliHelper
sourcefn validate(
&self,
ctx: &mut ValidationContext<'_>
) -> Result<ValidationResult, ReadlineError>
fn validate(
&self,
ctx: &mut ValidationContext<'_>
) -> Result<ValidationResult, ReadlineError>
Takes the currently edited
input and returns a
ValidationResult indicating whether it is valid or not along
with an option message to display about the result. The most
common validity check to implement is probably whether the
input is complete or not, for instance ensuring that all
delimiters are fully balanced. Read moresourcefn validate_while_typing(&self) -> bool
fn validate_while_typing(&self) -> bool
Configure whether validation is performed while typing or only
when user presses the Enter key. Read more
impl Helper for CliHelper